##  Creating a View
You can create up to 15 views for the dashboard and add them into custom groups, with a maximum of 10 groups.
To create a view, follow these steps:
  1. On the dashboard configuration page in the administration area, under Views, click Add View.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio38d1761e3b534fccac3a66a5e560bfcd_LowRes.png)
Selecting a View on the Architecture Executive Dashboard
  2. Enter a name for the view.
  3. Select a group to add the view to, or create a new one. The view and group names will appear in the View list on the dashboard, so make sure to use meaningful names. Consistent terminology ensures that all stakeholders understand the view’s purpose and can make relevant decisions.
  4. Apply inventory filters to the fact sheet types used in KPI calculations. For the fact sheet type you need, click Manage, then apply inventory filters and confirm your action.
  5. Save your changes.
